Grampus


Grampus Namespace

This is the namespace containing all Grampus backend functionality.

Modules Description

Board

Holds the functions related to a Board.

Eco

Holds the functions related to ECO classification.

Filters

Holds the functions related to Filters.

Game

Holds the functions related to a Move.

Games

Holds the functions related to a set of Games.

Grampus

Holds the functions related to the Grampus file.

Headers

Holds the functions related to Headers.

Index

Holds the functions related to an Index.

Move

Holds the functions related to a Move.

PgnGames

Holds the functions related to a set of Games in PGN format.

Piece

Holds the functions related to a Piece.

Repertoire

Holds the functions related to a Repertoire.

Result

Holds the functions related to the Game Result.

Tree

Holds the functions related to a Tree.

Types

Holds all the main types used by Grampus.