Grampus


Board Module

Namespace: Grampus

Assembly: GrampusLib.dll

Holds the functions related to a Board.

Functions and values

Function or value Description

FromFenStr fenstr

Full Usage: FromFenStr fenstr

Parameters:
    fenstr : string - The FEN string.

Returns: Brd The Board as a Brd type.

Create a new Board given a FEN string.

fenstr : string

The FEN string.

Returns: Brd

The Board as a Brd type.

FromSimpleStr str

Full Usage: FromSimpleStr str

Parameters:
    str : string - The simple string.

Returns: Brd The Board as a Brd type.

Create a new Board given a simple string.

str : string

The simple string.

Returns: Brd

The Board as a Brd type.

PossMoves bd sq

Full Usage: PossMoves bd sq

Parameters:
    bd : Brd - The Board as a Brd type.
    sq : Square - The Square as a Square type.

Returns: Move list The list of all possible moves.

Gets all possible moves for this Board from the specified Square.

bd : Brd

The Board as a Brd type.

sq : Square

The Square as a Square type.

Returns: Move list

The list of all possible moves.

Push mv bd

Full Usage: Push mv bd

Parameters:
    mv : Move - The move as a Move type.
    bd : Brd - The Board as a Brd type.

Returns: Brd The new Board as a Brd type.

Make an encoded Move for this Board and return the new Board.

mv : Move

The move as a Move type.

bd : Brd

The Board as a Brd type.

Returns: Brd

The new Board as a Brd type.

Start

Full Usage: Start

Returns: Brd

The starting Board at the beginning of a game

Returns: Brd

ToFenStr bd

Full Usage: ToFenStr bd

Parameters:
    bd : Brd - The Board as a Brd type.

Returns: string The FEN string.

Create a FEN string from this Board.

bd : Brd

The Board as a Brd type.

Returns: string

The FEN string.

ToSimpleStr bd

Full Usage: ToSimpleStr bd

Parameters:
    bd : Brd - The Board as a Brd type.

Returns: string The simple string.

Create a simple string from this Board.

bd : Brd

The Board as a Brd type.

Returns: string

The simple string.