Grampus


Game Module

Namespace: Grampus

Assembly: GrampusLib.dll

Holds the functions related to a Move.

Functions and values

Function or value Description

AddMv gm irs mv

Full Usage: AddMv gm irs mv

Parameters:
    gm : EncodedGame - The Encoded Game.
    irs : int list - The address within the game as an int list type.
    mv : Move - The Move.

Returns: EncodedGame * int list The changed Encoded Game and the new address.

Adds a Move to the Game given its address.

gm : EncodedGame

The Encoded Game.

irs : int list

The address within the game as an int list type.

mv : Move

The Move.

Returns: EncodedGame * int list

The changed Encoded Game and the new address.

AddNag gm irs nag

Full Usage: AddNag gm irs nag

Parameters:
    gm : EncodedGame - The Encoded Game.
    irs : int list - The address within the game as an int list type.
    nag : NAG - The NAG as a NAG type.

Returns: EncodedGame The changed Encoded Game.

Adds a NAG in the EncodedGame after the address provided.

gm : EncodedGame

The Encoded Game.

irs : int list

The address within the game as an int list type.

nag : NAG

The NAG as a NAG type.

Returns: EncodedGame

The changed Encoded Game.

AddRav gm irs mv

Full Usage: AddRav gm irs mv

Parameters:
    gm : EncodedGame - The Encoded Game.
    irs : int list - The address within the game as an int list type.
    mv : Move - The Move.

Returns: EncodedGame * int list The changed Encoded Game and the new address.

Adds a RAV to the Game given the Move is contains and its address.

gm : EncodedGame

The Encoded Game.

irs : int list

The address within the game as an int list type.

mv : Move

The Move.

Returns: EncodedGame * int list

The changed Encoded Game and the new address.

CommentAfter gm irs str

Full Usage: CommentAfter gm irs str

Parameters:
    gm : EncodedGame - The Encoded Game.
    irs : int list - The address within the game as an int list type.
    str : string - The comments as a string.

Returns: EncodedGame The changed Encoded Game.

Adds a comment to the Encoded Game after the address provided.

gm : EncodedGame

The Encoded Game.

irs : int list

The address within the game as an int list type.

str : string

The comments as a string.

Returns: EncodedGame

The changed Encoded Game.

CommentBefore gm irs str

Full Usage: CommentBefore gm irs str

Parameters:
    gm : EncodedGame - The Encoded Game.
    irs : int list - The address within the game as an int list type.
    str : string - The comments as a string.

Returns: EncodedGame The changed Encoded Game.

Adds a comment to the Encoded Game before the address provided.

gm : EncodedGame

The Encoded Game.

irs : int list

The address within the game as an int list type.

str : string

The comments as a string.

Returns: EncodedGame

The changed Encoded Game.

DeleteComment gm irs

Full Usage: DeleteComment gm irs

Parameters:
    gm : EncodedGame - The Encoded Game.
    irs : int list - The address within the game as an int list type.

Returns: EncodedGame The changed Encoded Game.

Deletes a comment in the Encoded Game at the address provided.

gm : EncodedGame

The Encoded Game.

irs : int list

The address within the game as an int list type.

Returns: EncodedGame

The changed Encoded Game.

DeleteNag gm irs

Full Usage: DeleteNag gm irs

Parameters:
    gm : EncodedGame - The Encoded Game.
    irs : int list - The address within the game as an int list type.

Returns: EncodedGame The changed Encoded Game.

Deletes a NAG in the Encoded Game at the address provided.

gm : EncodedGame

The Encoded Game.

irs : int list

The address within the game as an int list type.

Returns: EncodedGame

The changed Encoded Game.

DeleteRav gm irs

Full Usage: DeleteRav gm irs

Parameters:
    gm : EncodedGame - The Encoded Game.
    irs : int list - The address within the game as an int list type.

Returns: EncodedGame The changed Encoded Game.

Deletes a RAV in the EncodedGame at the address provided.

gm : EncodedGame

The Encoded Game.

irs : int list

The address within the game as an int list type.

Returns: EncodedGame

The changed Encoded Game.

EditComment gm irs str

Full Usage: EditComment gm irs str

Parameters:
    gm : EncodedGame - The Encoded Game.
    irs : int list - The address within the game as an int list type.
    str : string - The comments as a string.

Returns: EncodedGame The changed Encoded Game.

Edits a comment to the Encoded Game at the address provided.

gm : EncodedGame

The Encoded Game.

irs : int list

The address within the game as an int list type.

str : string

The comments as a string.

Returns: EncodedGame

The changed Encoded Game.

EditNag gm irs nag

Full Usage: EditNag gm irs nag

Parameters:
    gm : EncodedGame - The Encoded Game.
    irs : int list - The address within the game as an int list type.
    nag : NAG - The NAG as a NAG type.

Returns: EncodedGame The changed Encoded Game.

Edits a NAG in the Encoded Game at the address provided.

gm : EncodedGame

The Encoded Game.

irs : int list

The address within the game as an int list type.

nag : NAG

The NAG as a NAG type.

Returns: EncodedGame

The changed Encoded Game.

Encode ugm

Full Usage: Encode ugm

Parameters:
Returns: EncodedGame The Encoded Game.

Encodes the Game.

ugm : UnencodedGame

The Unencoded Game.

Returns: EncodedGame

The Encoded Game.

FromStr pgnstr

Full Usage: FromStr pgnstr

Parameters:
    pgnstr : string - The PGN string.

Returns: UnencodedGame The new Encoded Game.

Create an Encoded Game from a PGN string.

pgnstr : string

The PGN string.

Returns: UnencodedGame

The new Encoded Game.

GetPosns ply gm

Full Usage: GetPosns ply gm

Parameters:
    ply : int - The ply to process to, -1 for all moves.
    gm : EncodedGame - The Encoded Game.

Returns: string[] The arrays of Positions as strings.

Gets the Positions up to the specified ply.

ply : int

The ply to process to, -1 for all moves.

gm : EncodedGame

The Encoded Game.

Returns: string[]

The arrays of Positions as strings.

GetPosnsMoves ply gm

Full Usage: GetPosnsMoves ply gm

Parameters:
    ply : int - The ply to process to, -1 for all moves.
    gm : EncodedGame - The Encoded Game.

Returns: string[] * string[] The arrays of Positions and SANs as strings.

Gets the Positions and Sans up to the specified ply.

ply : int

The ply to process to, -1 for all moves.

gm : EncodedGame

The Encoded Game.

Returns: string[] * string[]

The arrays of Positions and SANs as strings.

NAGDesc nag

Full Usage: NAGDesc nag

Parameters:
    nag : NAG - The NAG as a NAG type.

Returns: string The NAG description.

Gets a NAG as a description such as Good given one of the list from Game.MoveText.

nag : NAG

The NAG as a NAG type.

Returns: string

The NAG description.

NAGFromStr str

Full Usage: NAGFromStr str

Parameters:
    str : string - The NAG string.

Returns: NAG The NAG type, such as NAG.Good.

Gets a NAG from a string such as ??.

str : string

The NAG string.

Returns: NAG

The NAG type, such as NAG.Good.

NAGHtm nag

Full Usage: NAGHtm nag

Parameters:
    nag : NAG - The NAG as a NAG type.

Returns: string The NAG HTML string.

Gets a NAG as HTML such as ?? given one of the list from Game.MoveText.

nag : NAG

The NAG as a NAG type.

Returns: string

The NAG HTML string.

NAGStr nag

Full Usage: NAGStr nag

Parameters:
    nag : NAG - The NAG as a NAG type.

Returns: string The NAG string.

Gets a NAG as a string such as ?? given one of the list from Game.MoveText.

nag : NAG

The NAG as a NAG type.

Returns: string

The NAG string.

NAGlist

Full Usage: NAGlist

Returns: NAG list

Gets a list of all NAGs supported

Returns: NAG list

RemoveComments gm

Full Usage: RemoveComments gm

Parameters:
Returns: EncodedGame The changed Encoded Game.

Removes all comments in the Encoded Game.

gm : EncodedGame

The Encoded Game.

Returns: EncodedGame

The changed Encoded Game.

RemoveNags gm

Full Usage: RemoveNags gm

Parameters:
Returns: EncodedGame The changed Encoded Game.

Removes all NAGs in the Encoded Game.

gm : EncodedGame

The Encoded Game.

Returns: EncodedGame

The changed Encoded Game.

RemoveRavs gm

Full Usage: RemoveRavs gm

Parameters:
Returns: EncodedGame The changed Encoded Game.

Removes all variations in the Encoded Game.

gm : EncodedGame

The Encoded Game.

Returns: EncodedGame

The changed Encoded Game.

Start

Full Usage: Start

Returns: EncodedGame

The starting Game with no moves

Returns: EncodedGame

Strip gm irs

Full Usage: Strip gm irs

Parameters:
    gm : EncodedGame - The Encoded Game.
    irs : int list - The address within the game as an int list type.

Returns: EncodedGame The changed Encoded Game.

Strips moves until end of game at the address provided.

gm : EncodedGame

The Encoded Game.

irs : int list

The address within the game as an int list type.

Returns: EncodedGame

The changed Encoded Game.

ToStr gm

Full Usage: ToStr gm

Parameters:
Returns: string The new PGN string.

Create a PGN string from an Encoded Game.

gm : EncodedGame

The Encoded Game.

Returns: string

The new PGN string.