Grampus


Games Module

Namespace: Grampus

Assembly: GrampusLib.dll

Holds the functions related to a set of Games.

Functions and values

Function or value Description

Add nm gms cb

Full Usage: Add nm gms cb

Parameters:
    nm : string - The full path and file name.
    gms : seq<EncodedGame> - The games as an EncodedGame sequence type.
    cb : int -> unit - Callback function to report on progress.

Adds a sequence of games to an existing base in the specified folder.

nm : string

The full path and file name.

gms : seq<EncodedGame>

The games as an EncodedGame sequence type.

cb : int -> unit

Callback function to report on progress.

AddGmp nm addnm cb

Full Usage: AddGmp nm addnm cb

Parameters:
    nm : string - The full path and file name.
    addnm : string - The full path and file name of the base with the games to add.
    cb : int -> unit - Callback function to report on progress.

Adds a sequence of games to an existing base in the specified folder.

nm : string

The full path and file name.

addnm : string

The full path and file name of the base with the games to add.

cb : int -> unit

Callback function to report on progress.

AppendGame nm gm

Full Usage: AppendGame nm gm

Parameters:
    nm : string - The full path and file name.
    gm : EncodedGame - The game as an EncodedGame type.

Adds game to an existing base in the specified folder.

nm : string

The full path and file name.

gm : EncodedGame

The game as an EncodedGame type.

Compact nm cb

Full Usage: Compact nm cb

Parameters:
    nm : string - The full path and file name.
    cb : int -> unit - Callback function to report on progress.

Returns: string Messages from compaction process as a string type.

Compacts the base in the specified folder.

nm : string

The full path and file name.

cb : int -> unit

Callback function to report on progress.

Returns: string

Messages from compaction process as a string type.

ExtractNewer nm trgnm year cb

Full Usage: ExtractNewer nm trgnm year cb

Parameters:
    nm : string - The full path and name of the source base.
    trgnm : string - The full path and name of the target base.
    year : int - The first year to include.
    cb : int -> unit - Callback function to report on progress.

Extracts newer games to the specified base.

nm : string

The full path and name of the source base.

trgnm : string

The full path and name of the target base.

year : int

The first year to include.

cb : int -> unit

Callback function to report on progress.

ExtractPlayer nm trgnm player cb

Full Usage: ExtractPlayer nm trgnm player cb

Parameters:
    nm : string - The full path and name of the source base.
    trgnm : string - The full path and name of the target base.
    player : string - The name of the player to include.
    cb : int -> unit - Callback function to report on progress.

Extracts player's games to the specified base.

nm : string

The full path and name of the source base.

trgnm : string

The full path and name of the target base.

player : string

The name of the player to include.

cb : int -> unit

Callback function to report on progress.

ExtractStronger nm trgnm grade cb

Full Usage: ExtractStronger nm trgnm grade cb

Parameters:
    nm : string - The full path and name of the source base.
    trgnm : string - The full path and name of the target base.
    grade : int - The minimum grade to include.
    cb : int -> unit - Callback function to report on progress.

Extracts stronger games to the specified base.

nm : string

The full path and name of the source base.

trgnm : string

The full path and name of the target base.

grade : int

The minimum grade to include.

cb : int -> unit

Callback function to report on progress.

GetPossNames nm cb

Full Usage: GetPossNames nm cb

Parameters:
    nm : string - The full path and file name.
    cb : string - Callback function to report on progress.

Returns: (int -> unit) -> string[] Possible names as a string array type.

Gets possible names of Players given part of the name string.

nm : string

The full path and file name.

cb : string

Callback function to report on progress.

Returns: (int -> unit) -> string[]

Possible names as a string array type.

LoadGame nm ie hdr

Full Usage: LoadGame nm ie hdr

Parameters:
    nm : string - The full path and file name.
    ie : IndexEntry - The index entry for the game as an IndexEntry type.
    hdr : Header - The header for the game as a Header type.

Returns: EncodedGame The encoded game.

Loads an encoded game given the folder, index entry and the header.

nm : string

The full path and file name.

ie : IndexEntry

The index entry for the game as an IndexEntry type.

hdr : Header

The header for the game as a Header type.

Returns: EncodedGame

The encoded game.

RemoveComments nm cb

Full Usage: RemoveComments nm cb

Parameters:
    nm : string - The full path and file name.
    cb : int -> unit - Callback function to report on progress.

Removes all Comments for the base in the specified folder.

nm : string

The full path and file name.

cb : int -> unit

Callback function to report on progress.

RemoveDuplicates nm cb

Full Usage: RemoveDuplicates nm cb

Parameters:
    nm : string - The full path and file name.
    cb : int -> unit - Callback function to report on progress.

Returns: string Messages from process as a string type.

Removes duplicate games for the base in the specified folder.

nm : string

The full path and file name.

cb : int -> unit

Callback function to report on progress.

Returns: string

Messages from process as a string type.

RemoveNags nm cb

Full Usage: RemoveNags nm cb

Parameters:
    nm : string - The full path and file name.
    cb : int -> unit - Callback function to report on progress.

Removes all NAGs for the base in the specified folder.

nm : string

The full path and file name.

cb : int -> unit

Callback function to report on progress.

RemoveRavs nm cb

Full Usage: RemoveRavs nm cb

Parameters:
    nm : string - The full path and file name.
    cb : int -> unit - Callback function to report on progress.

Removes all Variations for the base in the specified folder.

nm : string

The full path and file name.

cb : int -> unit

Callback function to report on progress.

Save nm gms cb

Full Usage: Save nm gms cb

Parameters:
    nm : string - The full path and file name.
    gms : seq<EncodedGame> - The games as an EncodedGame sequence type.
    cb : int -> unit - Callback function to report on progress.

Saves a sequence of games to create a new base in the specified folder.

nm : string

The full path and file name.

gms : seq<EncodedGame>

The games as an EncodedGame sequence type.

cb : int -> unit

Callback function to report on progress.

UpdateGame nm gnum gm

Full Usage: UpdateGame nm gnum gm

Parameters:
    nm : string - The full path and file name.
    gnum : int - The game number to update a int type.
    gm : EncodedGame - The game as an EncodedGame type.

Updates a game in an existing base in the specified folder.

nm : string

The full path and file name.

gnum : int

The game number to update a int type.

gm : EncodedGame

The game as an EncodedGame type.