Grampus


Grampus Module

Namespace: Grampus

Assembly: GrampusLib.dll

Holds the functions related to the Grampus file.

Functions and values

Function or value Description

Copy (nm, copynm)

Full Usage: Copy (nm, copynm)

Parameters:
    nm : string - The full path and file name of the source.
    copynm : string - The full path and file name of the target.

Copies a Grampus File and related content given the full path and file name of source and target.

nm : string

The full path and file name of the source.

copynm : string

The full path and file name of the target.

Delete nm

Full Usage: Delete nm

Parameters:
    nm : string - The full path and file name.

Deletes a Grampus File and related content given the full path and file name.

nm : string

The full path and file name.

DeleteFilters nm

Full Usage: DeleteFilters nm

Parameters:
    nm : string - The full path and file name.

Returns: GrampusData The contents of the new file as a GrampusData type.

Deletes the filters stored in a Base given the full path and file name and returns the new Grampus file.

nm : string

The full path and file name.

Returns: GrampusData

The contents of the new file as a GrampusData type.

DeleteGamesFilters nm

Full Usage: DeleteGamesFilters nm

Parameters:
    nm : string - The full path and file name.

Returns: GrampusData The contents of the new file as a GrampusData type.

Deletes the filters and games stored in a Base given the full path and file name and returns the new Grampus file.

nm : string

The full path and file name.

Returns: GrampusData

The contents of the new file as a GrampusData type.

DeleteTree nm

Full Usage: DeleteTree nm

Parameters:
    nm : string - The full path and file name.

Returns: GrampusData The contents of the new file as a GrampusData type.

Deletes the tree stored in a Base given the full path and file name and returns the new Grampus file.

nm : string

The full path and file name.

Returns: GrampusData

The contents of the new file as a GrampusData type.

Load nm

Full Usage: Load nm

Parameters:
    nm : string - The full path and file name.

Returns: GrampusData The contents of the file as a GrampusData type.

Loads a Grampus File given the full path and file name.

nm : string

The full path and file name.

Returns: GrampusData

The contents of the file as a GrampusData type.

New nm

Full Usage: New nm

Parameters:
    nm : string - The full path and file name.

Returns: GrampusData The contents of the new file as a GrampusData type.

Creates a new Grampus File given the full path and file name.

nm : string

The full path and file name.

Returns: GrampusData

The contents of the new file as a GrampusData type.

Save (nm, gmp)

Full Usage: Save (nm, gmp)

Parameters:
    nm : string - The full path and file name.
    gmp : GrampusData - The contents of the file as a GrampusData type.

Saves a Grampus File given the full path and file name and the data.

nm : string

The full path and file name.

gmp : GrampusData

The contents of the file as a GrampusData type.