Grampus


PgnGames Module

Namespace: Grampus

Assembly: GrampusLib.dll

Holds the functions related to a set of Games in PGN format.

Functions and values

Function or value Description

GetNumberOfGames fn

Full Usage: GetNumberOfGames fn

Parameters:
    fn : string - The path and file name of the PGN file.

Returns: int The number of games as an int type.

Gets the Number of Games from a PGN file.

fn : string

The path and file name of the PGN file.

Returns: int

The number of games as an int type.

ReadSeqFromFile fn

Full Usage: ReadSeqFromFile fn

Parameters:
    fn : string - The path and file name of the PGN file.

Returns: seq<UnencodedGame> The games as an UnencodeGame sequence.

Gets a Sequence of Games from a PGN file.

fn : string

The path and file name of the PGN file.

Returns: seq<UnencodedGame>

The games as an UnencodeGame sequence.