Grampus


Tree Module

Namespace: Grampus

Assembly: GrampusLib.dll

Holds the functions related to a Tree.

Functions and values

Function or value Description

Create nm

Full Usage: Create nm

Parameters:
    nm : string - The full path and file name.

Creates the tree storage given a folder.

nm : string

The full path and file name.

Read (posn, nm)

Full Usage: Read (posn, nm)

Parameters:
    posn : string - The position to read in the tree.
    nm : string - The full path and file name.

Returns: stats The tree for the posn as a stats type.

Reads the tree storage given a position and a folder.

posn : string

The position to read in the tree.

nm : string

The full path and file name.

Returns: stats

The tree for the posn as a stats type.

Save (posns, sts, nm)

Full Usage: Save (posns, sts, nm)

Parameters:
    posns : string[] - The array of positions for the tree.
    sts : stats[] - The array of stats for the tree.
    nm : string - The full path and file name.

Saves the tree storage given an array of positions, an array of stats and a folder.

posns : string[]

The array of positions for the tree.

sts : stats[]

The array of stats for the tree.

nm : string

The full path and file name.