Filters Module
Namespace:
Grampus
Assembly: GrampusLib.dll
Holds the functions related to Filters.
Functions and values
|
|
Creates the filter storage given a folder.
-
nm
:
string
-
The full path and file name.
|
|
|
Reads the filter storage given a position and a folder.
-
posn
:
string
-
The position to read in the tree.
-
nm
:
string
-
The full path and file name.
-
Returns:
int list
-
The filter for the posn as an int list type.
|
|
|
Saves the filter storage given an array of positions, an array of references to games and a folder.
-
posns
:
string[]
-
The array of positions for the tree.
-
filts
:
int list[]
-
The array of references to games as an int list type.
-
nm
:
string
-
The full path and file name.
|