Namespace: Grampus
Assembly: GrampusLib.dll
| Function or value | Description |
Full Usage:
AddMv gm irs mv
Parameters:
EncodedGame
-
The Encoded Game.
irs : int list
-
The address within the game as an int list type.
mv : Move
-
The Move.
Returns: EncodedGame * int list
The changed Encoded Game and the new address.
|
|
Full Usage:
AddNag gm irs nag
Parameters:
EncodedGame
-
The Encoded Game.
irs : int list
-
The address within the game as an int list type.
nag : NAG
-
The NAG as a NAG type.
Returns: EncodedGame
The changed Encoded Game.
|
|
Full Usage:
AddRav gm irs mv
Parameters:
EncodedGame
-
The Encoded Game.
irs : int list
-
The address within the game as an int list type.
mv : Move
-
The Move.
Returns: EncodedGame * int list
The changed Encoded Game and the new address.
|
|
Full Usage:
CommentAfter gm irs str
Parameters:
EncodedGame
-
The Encoded Game.
irs : int list
-
The address within the game as an int list type.
str : string
-
The comments as a string.
Returns: EncodedGame
The changed Encoded Game.
|
|
Full Usage:
CommentBefore gm irs str
Parameters:
EncodedGame
-
The Encoded Game.
irs : int list
-
The address within the game as an int list type.
str : string
-
The comments as a string.
Returns: EncodedGame
The changed Encoded Game.
|
|
Full Usage:
DeleteComment gm irs
Parameters:
EncodedGame
-
The Encoded Game.
irs : int list
-
The address within the game as an int list type.
Returns: EncodedGame
The changed Encoded Game.
|
|
Full Usage:
DeleteNag gm irs
Parameters:
EncodedGame
-
The Encoded Game.
irs : int list
-
The address within the game as an int list type.
Returns: EncodedGame
The changed Encoded Game.
|
|
Full Usage:
DeleteRav gm irs
Parameters:
EncodedGame
-
The Encoded Game.
irs : int list
-
The address within the game as an int list type.
Returns: EncodedGame
The changed Encoded Game.
|
|
Full Usage:
EditComment gm irs str
Parameters:
EncodedGame
-
The Encoded Game.
irs : int list
-
The address within the game as an int list type.
str : string
-
The comments as a string.
Returns: EncodedGame
The changed Encoded Game.
|
|
Full Usage:
EditNag gm irs nag
Parameters:
EncodedGame
-
The Encoded Game.
irs : int list
-
The address within the game as an int list type.
nag : NAG
-
The NAG as a NAG type.
Returns: EncodedGame
The changed Encoded Game.
|
|
Full Usage:
Encode ugm
Parameters:
UnencodedGame
-
The Unencoded Game.
Returns: EncodedGame
The Encoded Game.
|
|
Full Usage:
FromStr pgnstr
Parameters:
string
-
The PGN string.
Returns: UnencodedGame
The new Encoded Game.
|
|
Full Usage:
GetPosns ply gm
Parameters:
int
-
The ply to process to, -1 for all moves.
gm : EncodedGame
-
The Encoded Game.
Returns: string[]
The arrays of Positions as strings.
|
|
Full Usage:
GetPosnsMoves ply gm
Parameters:
int
-
The ply to process to, -1 for all moves.
gm : EncodedGame
-
The Encoded Game.
Returns: string[] * string[]
The arrays of Positions and SANs as strings.
|
|
Full Usage:
NAGDesc nag
Parameters:
NAG
-
The NAG as a NAG type.
Returns: string
The NAG description.
|
|
Full Usage:
NAGFromStr str
Parameters:
string
-
The NAG string.
Returns: NAG
The NAG type, such as NAG.Good.
|
|
Full Usage:
NAGHtm nag
Parameters:
NAG
-
The NAG as a NAG type.
Returns: string
The NAG HTML string.
|
|
Full Usage:
NAGStr nag
Parameters:
NAG
-
The NAG as a NAG type.
Returns: string
The NAG string.
|
|
|
|
|
Full Usage:
RemoveComments gm
Parameters:
EncodedGame
-
The Encoded Game.
Returns: EncodedGame
The changed Encoded Game.
|
|
Full Usage:
RemoveNags gm
Parameters:
EncodedGame
-
The Encoded Game.
Returns: EncodedGame
The changed Encoded Game.
|
|
Full Usage:
RemoveRavs gm
Parameters:
EncodedGame
-
The Encoded Game.
Returns: EncodedGame
The changed Encoded Game.
|
|
|
|
Full Usage:
Strip gm irs
Parameters:
EncodedGame
-
The Encoded Game.
irs : int list
-
The address within the game as an int list type.
Returns: EncodedGame
The changed Encoded Game.
|
|
Full Usage:
ToStr gm
Parameters:
EncodedGame
-
The Encoded Game.
Returns: string
The new PGN string.
|
|