Namespace: Grampus
Assembly: GrampusLib.dll
| Function or value | Description |
Full Usage:
Add nm gms cb
Parameters:
string
-
The full path and file name.
gms : seq<EncodedGame>
-
The games as an EncodedGame sequence type.
cb : int -> unit
-
Callback function to report on progress.
|
|
Full Usage:
AddGmp nm addnm cb
Parameters:
string
-
The full path and file name.
addnm : string
-
The full path and file name of the base with the games to add.
cb : int -> unit
-
Callback function to report on progress.
|
|
Full Usage:
AppendGame nm gm
Parameters:
string
-
The full path and file name.
gm : EncodedGame
-
The game as an EncodedGame type.
|
|
Full Usage:
Compact nm cb
Parameters:
string
-
The full path and file name.
cb : int -> unit
-
Callback function to report on progress.
Returns: string
Messages from compaction process as a string type.
|
|
Full Usage:
ExtractNewer nm trgnm year cb
Parameters:
string
-
The full path and name of the source base.
trgnm : string
-
The full path and name of the target base.
year : int
-
The first year to include.
cb : int -> unit
-
Callback function to report on progress.
|
|
Full Usage:
ExtractPlayer nm trgnm player cb
Parameters:
string
-
The full path and name of the source base.
trgnm : string
-
The full path and name of the target base.
player : string
-
The name of the player to include.
cb : int -> unit
-
Callback function to report on progress.
|
|
Full Usage:
ExtractStronger nm trgnm grade cb
Parameters:
string
-
The full path and name of the source base.
trgnm : string
-
The full path and name of the target base.
grade : int
-
The minimum grade to include.
cb : int -> unit
-
Callback function to report on progress.
|
|
Full Usage:
GetPossNames nm cb
Parameters:
string
-
The full path and file name.
cb : string
-
Callback function to report on progress.
Returns: (int -> unit) -> string[]
Possible names as a string array type.
|
|
Full Usage:
LoadGame nm ie hdr
Parameters:
string
-
The full path and file name.
ie : IndexEntry
-
The index entry for the game as an IndexEntry type.
hdr : Header
-
The header for the game as a Header type.
Returns: EncodedGame
The encoded game.
|
|
Full Usage:
RemoveComments nm cb
Parameters:
string
-
The full path and file name.
cb : int -> unit
-
Callback function to report on progress.
|
|
Full Usage:
RemoveDuplicates nm cb
Parameters:
string
-
The full path and file name.
cb : int -> unit
-
Callback function to report on progress.
Returns: string
Messages from process as a string type.
|
|
Full Usage:
RemoveNags nm cb
Parameters:
string
-
The full path and file name.
cb : int -> unit
-
Callback function to report on progress.
|
|
Full Usage:
RemoveRavs nm cb
Parameters:
string
-
The full path and file name.
cb : int -> unit
-
Callback function to report on progress.
|
|
Full Usage:
Save nm gms cb
Parameters:
string
-
The full path and file name.
gms : seq<EncodedGame>
-
The games as an EncodedGame sequence type.
cb : int -> unit
-
Callback function to report on progress.
|
|
Full Usage:
UpdateGame nm gnum gm
Parameters:
string
-
The full path and file name.
gnum : int
-
The game number to update a int type.
gm : EncodedGame
-
The game as an EncodedGame type.
|
|