Namespace: Grampus
Assembly: GrampusLib.dll
| Function or value | Description |
Full Usage:
Copy (nm, copynm)
Parameters:
string
-
The full path and file name of the source.
copynm : string
-
The full path and file name of the target.
|
|
Full Usage:
Delete nm
Parameters:
string
-
The full path and file name.
|
|
Full Usage:
DeleteFilters nm
Parameters:
string
-
The full path and file name.
Returns: GrampusData
The contents of the new file as a GrampusData type.
|
|
Full Usage:
DeleteGamesFilters nm
Parameters:
string
-
The full path and file name.
Returns: GrampusData
The contents of the new file as a GrampusData type.
|
|
Full Usage:
DeleteTree nm
Parameters:
string
-
The full path and file name.
Returns: GrampusData
The contents of the new file as a GrampusData type.
|
|
Full Usage:
Load nm
Parameters:
string
-
The full path and file name.
Returns: GrampusData
The contents of the file as a GrampusData type.
|
|
Full Usage:
New nm
Parameters:
string
-
The full path and file name.
Returns: GrampusData
The contents of the new file as a GrampusData type.
|
|
Full Usage:
Save (nm, gmp)
Parameters:
string
-
The full path and file name.
gmp : GrampusData
-
The contents of the file as a GrampusData type.
|
|